@@ -2,7 +2,7 @@ package Map::Tube::Plugin::FuzzyFind;
 
 use strict;
 use warnings;
-$Map::Tube::Plugin::FuzzyFind::VERSION = '0.05';
+$Map::Tube::Plugin::FuzzyFind::VERSION = '0.06';
 
 =head1 NAME
 
@@ -10,7 +10,7 @@ Map::Tube::Plugin::FuzzyFind - Map::Tube add-on for finding stations and lines b
 
 =head1 VERSION
 
-Version 0.05
+Version 0.05_01 -- Internal development only, do not use in public
 
 =cut
 
@@ -188,9 +188,11 @@ no limit will be applied. In scalar context, this parameter is disregarded.
 # name space pollution of Map::Tube::xxx. Other solutions are possible,
 # but currently it is felt they would introduce more hassle than clarity.
 
-sub fuzzy_find {  ## no critic(Subroutines::ProhibitExcessComplexity)
+
+sub fuzzy_find {    ## no critic(Subroutines::ProhibitExcessComplexity)
   my( $self, @tmpargs ) = @_;
   my( %args, $pattern );
+
   # *** This needs to be re-organised into a hash with pointers to methods.
   my %methods = ( exact       => 1,
                   start       => 2,
@@ -255,26 +257,26 @@ sub fuzzy_find {  ## no critic(Subroutines::ProhibitExcessComplexity)
   my $nmethod = $methods{ lc( $args{method} ) } || 1;
 
   my @result;
-  if ( $nmethod == 1 ) { ## no critic(ControlStructures::ProhibitCascadingIfElse)
+  if ( $nmethod == 1 ) {    ## no critic(ControlStructures::ProhibitCascadingIfElse)
 
     # Exact matching (up to case)
     $pattern = lc($pattern);
-    @result  = sort { $a->name() cmp $b->name() } grep { lc( $_->name() ) eq $pattern } @{ $source };
+    @result  = sort { $a->name() cmp $b->name() } grep { lc( $_->name() ) eq $pattern } @{$source};
   } elsif ( $nmethod == 2 ) {
 
     # Match at start
     $pattern = lc($pattern);
-    @result  = sort { $a->name() cmp $b->name() } grep { index( lc( $_->name() ), $pattern ) == 0 } @{ $source };
+    @result  = sort { $a->name() cmp $b->name() } grep { index( lc( $_->name() ), $pattern ) == 0 } @{$source};
   } elsif ( $nmethod == 3 ) {
 
     # Match some substring
     $pattern = lc($pattern);
-    @result  = sort { $a->name() cmp $b->name() } grep { index( lc( $_->name() ), $pattern ) >= 0 } @{ $source };
+    @result  = sort { $a->name() cmp $b->name() } grep { index( lc( $_->name() ), $pattern ) >= 0 } @{$source};
   } elsif ( $nmethod == 4 ) {
 
     # Match regex
     $pattern = qr/$pattern/i unless ref($pattern) eq 'Regexp';
-    @result  = sort { $a->name() cmp $b->name() } grep { $_->name() =~ $pattern } @{ $source };
+    @result  = sort { $a->name() cmp $b->name() } grep { $_->name() =~ $pattern } @{$source};
   } elsif ( ( $nmethod >= 5 ) && ( $nmethod <= 8 ) ) {
 
     # Use some well-known fuzzy matcher
@@ -291,9 +293,9 @@ sub fuzzy_find {  ## no critic(Subroutines::ProhibitExcessComplexity)
         croak unless $loaded;
         my $pattern_soundex = Text::Soundex::soundex_unicode($pattern);
         $matcher = sub {
-                         return ( Text::Soundex::soundex_unicode($_[0]) eq $pattern_soundex ) ? 0 : 1;
-                       };
-        $args{maxdist} = 0.5; # so that exactly the matches will be retained in the map - sort - grep.
+          return ( Text::Soundex::soundex_unicode( $_[0] ) eq $pattern_soundex ) ? 0 : 1;
+        };
+        $args{maxdist} = 0.5;    # so that exactly the matches will be retained in the map - sort - grep.
       } elsif ( $nmethod == 6 ) {
 
         # Metaphone, (claiming to be) "A modern Soundex". Still with a slant towards English pronunciation.
@@ -302,9 +304,9 @@ sub fuzzy_find {  ## no critic(Subroutines::ProhibitExcessComplexity)
         croak unless $loaded;
         my $pattern_metacode = Text::Metaphone::Metaphone($pattern);
         $matcher = sub {
-                         return ( Text::Metaphone::Metaphone($_[0]) eq $pattern_metacode ) ? 0 : 1;
-                       };
-        $args{maxdist} = 0.5; # so that exactly the matches will be retained in the map - sort - grep.
+          return ( Text::Metaphone::Metaphone( $_[0] ) eq $pattern_metacode ) ? 0 : 1;
+        };
+        $args{maxdist} = 0.5;    # so that exactly the matches will be retained in the map - sort - grep.
       } elsif ( $nmethod == 7 ) {
 
         # Levenshtein edit distance
@@ -321,26 +323,26 @@ sub fuzzy_find {  ## no critic(Subroutines::ProhibitExcessComplexity)
         $module = 'String::Trigram';
         $loaded = eval qq{ require $module; 1 };
         croak unless $loaded;
-        $args{maxdist} ||= length($pattern)/2;
+        $args{maxdist} ||= length($pattern) / 2;
         my %st_args;
-        $st_args{minSim}     = 1 - $args{maxdist}/length($pattern);
-        $st_args{minSim}     = 0 if ( $st_args{minSim} < 0 );
-        $st_args{minSim}     = 1 if ( $st_args{minSim} > 1 );
-        $st_args{ngram}      = $args{windowsize} || 3;
-        $st_args{warp}       = 2;
-        $st_args{cmpBase}    = [ $pattern ];
+        $st_args{minSim}  = 1 - $args{maxdist} / length($pattern);
+        $st_args{minSim}  = 0 if ( $st_args{minSim} < 0 );
+        $st_args{minSim}  = 1 if ( $st_args{minSim} > 1 );
+        $st_args{ngram}   = $args{windowsize} || 3;
+        $st_args{warp}    = 2;
+        $st_args{cmpBase} = [$pattern];
         my $trigrammer = String::Trigram->new(%st_args);
         $matcher = sub {
-                         my $str = $_[0];
-                         $str =~ s/\s+//g;
-                         my %result;
-                         my $nresults = $trigrammer->getSimilarStrings( $str, \%result );
-                         return $nresults ? ( (1 - $result{$pattern}) * length($pattern) ) : ( length($pattern) + 1 );
-                       };
-      }
-    }
+          my $str = $_[0];
+          $str =~ s/\s+//g;
+          my %result;
+          my $nresults = $trigrammer->getSimilarStrings( $str, \%result );
+          return $nresults ? ( ( 1 - $result{$pattern} ) * length($pattern) ) : ( length($pattern) + 1 );
+        };
+      } ## end elsif ( $nmethod == 8 )
+    } ## end try
     catch {
-      croak "Matcher module $module not found";
+      croak "Matcher module $module not loaded or not executed: $_";
     };
 
     # $matcher is now a coderef that takes one argument, viz., a string to match.
@@ -348,12 +350,12 @@ sub fuzzy_find {  ## no critic(Subroutines::ProhibitExcessComplexity)
     # In case of matchers that provide just a "match/no match" information,
     # 0 means "match" and 1 means "no match".
 
-    my %name2obj = map  { $_->name() => $_ } @{ $source };
+    my %name2obj = map { $_->name() => $_ } @{$source};
 
-    my %distance = map  { $_ => $matcher->( lc($_) ) } keys %name2obj;
-    @result      = map  { $name2obj{$_} }
-                   sort { ( $distance{$a} <=> $distance{$b} ) || ( $a cmp $b ) }
-                   grep { ( $args{maxdist} <= 0 )             || ( $distance{$_} <= $args{maxdist} ) } keys %distance;
+    my %distance = map { $_ => $matcher->( lc($_) ) } keys %name2obj;
+    @result = map { $name2obj{$_} }
+      sort { ( $distance{$a} <=> $distance{$b} ) || ( $a cmp $b ) }
+      grep { ( $args{maxdist} <= 0 )             || ( $distance{$_} <= $args{maxdist} ) } keys %distance;
   } else {
 
     # nada
@@ -378,13 +380,13 @@ L<Map::Tube>
 
 =head1 CONTRIBUTORS
 
-Thanks to Mohammad S Anwar, author of L<Map::Tube>, for great feedback, discussions, advice,
-and willingness to refactor his code.
+Thanks to Mohammad S Anwar, author of L<Map::Tube>, for that module, for great feedback,
+discussions, advice, debugging help, and willingness to refactor his code.
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-map-tube-plugin-fuzzyfind at rt.cpan.org>,  or
-through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Plugin-FuzzyFind>.
+through the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Plugin-FuzzyFind>.
 I will  be notified and then you'll automatically be notified of progress on your
 bug as I make changes.
 
